@@ -17,7 +17,7 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * (C) Copyright 2008 - 2010 Red Hat, Inc.
+ * (C) Copyright 2008 - 2011 Red Hat, Inc.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,8 +32,9 @@
 #include <nm-setting-cdma.h>
 #include <nm-setting-serial.h>
 #include <nm-setting-ppp.h>
-#include <nm-cdma-device.h>
+#include <nm-device-modem.h>
 #include <nm-utils.h>
+#include <nm-secret-agent.h>
 
 #include "applet.h"
 #include "applet-device-cdma.h"
@@ -48,6 +49,7 @@ typedef struct {
 	NMApplet *applet;
 	NMDevice *device;
 
+	DBusGConnection *bus;
 	DBusGProxy *props_proxy;
 	DBusGProxy *cdma_proxy;
 	gboolean quality_valid;
@@ -104,7 +106,7 @@ mobile_wizard_done (MobileWizard *wizard,
 		NMSetting *setting;
 		char *uuid, *id;
 
-		if (method->devtype != NM_DEVICE_TYPE_CDMA) {
+		if (method->devtype != NM_DEVICE_MODEM_CAPABILITY_CDMA_EVDO) {
 			g_warning ("Unexpected device type (not CDMA).");
 			canceled = TRUE;
 			goto done;
@@ -171,7 +173,7 @@ cdma_new_auto_connection (NMDevice *device,
 	info->callback = callback;
 	info->callback_data = callback_data;
 
-	wizard = mobile_wizard_new (NULL, NULL, NM_DEVICE_TYPE_CDMA, FALSE,
+	wizard = mobile_wizard_new (NULL, NULL, NM_DEVICE_MODEM_CAPABILITY_CDMA_EVDO, FALSE,
 	                            mobile_wizard_done, info);
 	if (wizard) {
 		mobile_wizard_present (wizard);
@@ -180,7 +182,7 @@ cdma_new_auto_connection (NMDevice *device,
 
 	/* Fall back to something */
 	method = g_malloc0 (sizeof (MobileWizardAccessMethod));
-	method->devtype = NM_DEVICE_TYPE_CDMA;
+	method->devtype = NM_DEVICE_MODEM_CAPABILITY_CDMA_EVDO;
 	method->provider_name = _("CDMA");
 	mobile_wizard_done (NULL, FALSE, method, info);
 	g_free (method);
@@ -448,38 +450,22 @@ cdma_get_icon (NMDevice *device,
 }
 
 typedef struct {
-	NMANewSecretsRequestedFunc callback;
-	gpointer callback_data;
-	NMApplet *applet;
-	NMSettingsConnectionInterface *connection;
-	NMActiveConnection *active_connection;
+	SecretsRequest req;
 	GtkWidget *dialog;
 	GtkEntry *secret_entry;
 	char *secret_name;
-} NMCdmaInfo;
+} NMCdmaSecretsInfo;
 
 static void
-destroy_cdma_dialog (gpointer user_data, GObject *finalized)
+free_cdma_secrets_info (SecretsRequest *req)
 {
-	NMCdmaInfo *info = user_data;
+	NMCdmaSecretsInfo *info = (NMCdmaSecretsInfo *) req;
 
-	gtk_widget_hide (info->dialog);
-	gtk_widget_destroy (info->dialog);
-
-	g_object_unref (info->connection);
-	g_free (info->secret_name);
-	g_free (info);
-}
-
-static void
-update_cb (NMSettingsConnectionInterface *connection,
-           GError *error,
-           gpointer user_data)
-{
-	if (error) {
-		g_warning ("%s: failed to update connection: (%d) %s",
-		           __func__, error->code, error->message);
+	if (info->dialog) {
+		gtk_widget_hide (info->dialog);
+		gtk_widget_destroy (info->dialog);
 	}
+	g_free (info->secret_name);
 }
 
 static void
@@ -487,133 +473,78 @@ get_cdma_secrets_cb (GtkDialog *dialog,
                      gint response,
                      gpointer user_data)
 {
-	NMCdmaInfo *info = (NMCdmaInfo *) user_data;
-	NMSettingCdma *setting;
-	GHashTable *settings_hash;
-	GHashTable *secrets;
-	GError *err = NULL;
+	SecretsRequest *req = user_data;
+	NMCdmaSecretsInfo *info = (NMCdmaSecretsInfo *) req;
+	NMSetting *setting;
+	GError *error = NULL;
 
-	/* Got a user response, clear the NMActiveConnection destroy handler for
-	 * this dialog since this function will now take over dialog destruction.
-	 */
-	g_object_weak_unref (G_OBJECT (info->active_connection), destroy_cdma_dialog, info);
-
-	if (response != GTK_RESPONSE_OK) {
-		g_set_error (&err,
-		             NM_SETTINGS_INTERFACE_ERROR,
-		             NM_SETTINGS_INTERFACE_ERROR_INTERNAL_ERROR,
-		             "%s.%d (%s): canceled",
-		             __FILE__, __LINE__, __func__);
-		goto done;
+	if (response == GTK_RESPONSE_OK) {
+		setting = nm_connection_get_setting (req->connection, NM_TYPE_SETTING_CDMA);
+		if (setting) {
+			g_object_set (G_OBJECT (setting),
+				          info->secret_name, gtk_entry_get_text (info->secret_entry),
+				          NULL);
+		} else {
+			error = g_error_new (NM_SECRET_AGENT_ERROR,
+				                 NM_SECRET_AGENT_ERROR_INTERNAL_ERROR,
+				                 "%s.%d (%s): no GSM setting",
+				                 __FILE__, __LINE__, __func__);
+		}
+	} else {
+		error = g_error_new (NM_SECRET_AGENT_ERROR,
+		                     NM_SECRET_AGENT_ERROR_USER_CANCELED,
+		                     "%s.%d (%s): canceled",
+		                     __FILE__, __LINE__, __func__);
 	}
 
-	setting = NM_SETTING_CDMA (nm_connection_get_setting (NM_CONNECTION (info->connection), NM_TYPE_SETTING_CDMA));
-
-	if (!strcmp (info->secret_name, NM_SETTING_CDMA_PASSWORD)) {
-		g_object_set (setting, 
-			      NM_SETTING_CDMA_PASSWORD, gtk_entry_get_text (info->secret_entry),
-			      NULL);
-	}
-
-	secrets = nm_setting_to_hash (NM_SETTING (setting));
-	if (!secrets) {
-		g_set_error (&err,
-		             NM_SETTINGS_INTERFACE_ERROR,
-		             NM_SETTINGS_INTERFACE_ERROR_INTERNAL_ERROR,
-		             "%s.%d (%s): failed to hash setting '%s'.",
-		             __FILE__, __LINE__, __func__, nm_setting_get_name (NM_SETTING (setting)));
-		goto done;
-	}
-
-	/* Returned secrets are a{sa{sv}}; this is the outer a{s...} hash that
-	 * will contain all the individual settings hashes.
-	 */
-	settings_hash = g_hash_table_new_full (g_str_hash, g_str_equal,
-								    g_free, (GDestroyNotify) g_hash_table_destroy);
-
-	g_hash_table_insert (settings_hash, g_strdup (nm_setting_get_name (NM_SETTING (setting))), secrets);
-	info->callback (info->connection, settings_hash, NULL, info->callback_data);
-	g_hash_table_destroy (settings_hash);
-
-	/* Save the connection back to GConf _after_ hashing it, because
-	 * saving to GConf might trigger the GConf change notifiers, resulting
-	 * in the connection being read back in from GConf which clears secrets.
-	 */
-	if (NMA_IS_GCONF_CONNECTION (info->connection))
-		nm_settings_connection_interface_update (info->connection, update_cb, NULL);
-
- done:
-	if (err) {
-		g_warning ("%s", err->message);
-		info->callback (info->connection, NULL, err, info->callback_data);
-		g_error_free (err);
-	}
-
-	nm_connection_clear_secrets (NM_CONNECTION (info->connection));
-	destroy_cdma_dialog (info, NULL);
+	applet_secrets_request_complete_setting (req, NM_SETTING_CDMA_SETTING_NAME, error);
+	applet_secrets_request_free (req);
+	g_clear_error (&error);
 }
 
 static gboolean
-cdma_get_secrets (NMDevice *device,
-                  NMSettingsConnectionInterface *connection,
-                  NMActiveConnection *active_connection,
-                  const char *setting_name,
-                  const char **hints,
-                  NMANewSecretsRequestedFunc callback,
-                  gpointer callback_data,
-                  NMApplet *applet,
-                  GError **error)
+cdma_get_secrets (SecretsRequest *req, GError **error)
 {
-	NMCdmaInfo *info;
+	NMCdmaSecretsInfo *info = (NMCdmaSecretsInfo *) req;
 	GtkWidget *widget;
 	GtkEntry *secret_entry = NULL;
 
-	if (!hints || !g_strv_length ((char **) hints)) {
+	applet_secrets_request_set_free_func (req, free_cdma_secrets_info);
+
+	if (!req->hints || !g_strv_length (req->hints)) {
 		g_set_error (error,
-		             NM_SETTINGS_INTERFACE_ERROR,
-		             NM_SETTINGS_INTERFACE_ERROR_INTERNAL_ERROR,
+		             NM_SECRET_AGENT_ERROR,
+		             NM_SECRET_AGENT_ERROR_INTERNAL_ERROR,
 		             "%s.%d (%s): missing secrets hints.",
 		             __FILE__, __LINE__, __func__);
 		return FALSE;
 	}
+	info->secret_name = g_strdup (req->hints[0]);
 
-	if (!strcmp (hints[0], NM_SETTING_CDMA_PASSWORD))
-		widget = applet_mobile_password_dialog_new (device, NM_CONNECTION (connection), &secret_entry);
+	if (!strcmp (info->secret_name, NM_SETTING_CDMA_PASSWORD))
+		widget = applet_mobile_password_dialog_new (req->connection, &secret_entry);
 	else {
 		g_set_error (error,
-		             NM_SETTINGS_INTERFACE_ERROR,
-		             NM_SETTINGS_INTERFACE_ERROR_INTERNAL_ERROR,
+		             NM_SECRET_AGENT_ERROR,
+		             NM_SECRET_AGENT_ERROR_INTERNAL_ERROR,
 		             "%s.%d (%s): unknown secrets hint '%s'.",
-		             __FILE__, __LINE__, __func__, hints[0]);
+		             __FILE__, __LINE__, __func__, info->secret_name);
 		return FALSE;
 	}
+	info->dialog = widget;
+	info->secret_entry = secret_entry;
 
 	if (!widget || !secret_entry) {
 		g_set_error (error,
-		             NM_SETTINGS_INTERFACE_ERROR,
-		             NM_SETTINGS_INTERFACE_ERROR_INTERNAL_ERROR,
+		             NM_SECRET_AGENT_ERROR,
+		             NM_SECRET_AGENT_ERROR_INTERNAL_ERROR,
 		             "%s.%d (%s): error asking for CDMA secrets.",
 		             __FILE__, __LINE__, __func__);
 		return FALSE;
 	}
 
-	info = g_new (NMCdmaInfo, 1);
-	info->callback = callback;
-	info->callback_data = callback_data;
-	info->applet = applet;
-	info->active_connection = active_connection;
-	info->connection = g_object_ref (connection);
-	info->secret_name = g_strdup (hints[0]);
-	info->dialog = widget;
-	info->secret_entry = secret_entry;
-
 	g_signal_connect (widget, "response", G_CALLBACK (get_cdma_secrets_cb), info);
 
-	/* Attach a destroy notifier to the NMActiveConnection so we can destroy
-	 * the dialog when the active connection goes away.
-	 */
-	g_object_weak_ref (G_OBJECT (active_connection), destroy_cdma_dialog, info);
-
 	gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
 	gtk_widget_realize (GTK_WIDGET (widget));
 	gtk_window_present (GTK_WINDOW (widget));
@@ -630,6 +561,8 @@ cdma_device_info_free (gpointer data)
 		g_object_unref (info->props_proxy);
 	if (info->cdma_proxy)
 		g_object_unref (info->cdma_proxy);
+	if (info->bus)
+		dbus_g_connection_unref (info->bus);
 	if (info->poll_id)
 		g_source_remove (info->poll_id);
 	if (info->providers)
@@ -639,44 +572,6 @@ cdma_device_info_free (gpointer data)
 	g_free (info);
 }
 
-static void
-notify_user_of_cdma_reg_change (CdmaDeviceInfo *info)
-{
-	guint32 mb_state = cdma_state_to_mb_state (info);
-
-	if (mb_state == MB_STATE_HOME) {
-		applet_do_notify_with_pref (info->applet,
-		                            _("CDMA network."),
-		                            _("You are now registered on the home network."),
-		                            "nm-signal-100",
-		                            PREF_DISABLE_CONNECTED_NOTIFICATIONS);
-	} else if (mb_state == MB_STATE_ROAMING) {
-		applet_do_notify_with_pref (info->applet,
-		                            _("CDMA network."),
-		                            _("You are now registered on a roaming network."),
-		                            "nm-signal-100",
-		                            PREF_DISABLE_CONNECTED_NOTIFICATIONS);
-	}
-}
-
-static void
-update_registration_state (CdmaDeviceInfo *info,
-                           guint32 new_cdma1x_state,
-                           guint32 new_evdo_state)
-{
-	guint32 old_mb_state = cdma_state_to_mb_state (info);
-
-	if (   (info->cdma1x_state != new_cdma1x_state)
-	    || (info->evdo_state != new_evdo_state)) {
-		info->cdma1x_state = new_cdma1x_state;
-		info->evdo_state = new_evdo_state;
-	}
-
-	/* Use the composite state to notify of home/roaming changes */
-	if (cdma_state_to_mb_state (info) != old_mb_state)
-		notify_user_of_cdma_reg_change (info);
-}
-
 static void
 reg_state_reply (DBusGProxy *proxy, DBusGProxyCall *call, gpointer user_data)
 {
@@ -688,7 +583,8 @@ reg_state_reply (DBusGProxy *proxy, DBusGProxyCall *call, gpointer user_data)
 	                           G_TYPE_UINT, &cdma1x_state,
 	                           G_TYPE_UINT, &evdo_state,
 	                           G_TYPE_INVALID)) {
-		update_registration_state (info, cdma1x_state, evdo_state);
+		info->cdma1x_state = cdma1x_state;
+		info->evdo_state = evdo_state;
 		applet_schedule_update_icon (info->applet);
 	}
 
@@ -876,8 +772,10 @@ reg_state_changed_cb (DBusGProxy *proxy,
 {
 	CdmaDeviceInfo *info = user_data;
 
-	update_registration_state (info, cdma1x_state, evdo_state);
+	info->cdma1x_state = cdma1x_state;
+	info->evdo_state = evdo_state;
 	info->skip_reg_poll = TRUE;
+
 	applet_schedule_update_icon (info->applet);
 }
 
@@ -928,19 +826,27 @@ modem_properties_changed (DBusGProxy *proxy,
 static void
 cdma_device_added (NMDevice *device, NMApplet *applet)
 {
-	NMCdmaDevice *cdma = NM_CDMA_DEVICE (device);
-	AppletDBusManager *dbus_mgr = applet_dbus_manager_get ();
-	DBusGConnection *bus = applet_dbus_manager_get_connection (dbus_mgr);
+	NMDeviceModem *modem = NM_DEVICE_MODEM (device);
 	CdmaDeviceInfo *info;
+	DBusGConnection *bus;
 	const char *udi;
+	GError *error = NULL;
 
 	udi = nm_device_get_udi (device);
 	if (!udi)
 		return;
 
+	bus = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
+	if (!bus) {
+		g_warning ("%s: failed to connect to D-Bus: (%d) %s", __func__, error->code, error->message);
+		g_clear_error (&error);
+		return;
+	}
+
 	info = g_malloc0 (sizeof (CdmaDeviceInfo));
 	info->applet = applet;
 	info->device = device;
+	info->bus = bus;
 	info->quality_valid = FALSE;
 
 	info->providers = nmn_mobile_providers_parse (NULL);
@@ -965,7 +871,7 @@ cdma_device_added (NMDevice *device, NMApplet *applet)
 		return;
 	}
 
-	g_object_set_data_full (G_OBJECT (cdma), "devinfo", info, cdma_device_info_free);
+	g_object_set_data_full (G_OBJECT (modem), "devinfo", info, cdma_device_info_free);
 
 	/* Registration state change signal */
 	dbus_g_object_register_marshaller (nma_marshal_VOID__UINT_UINT,
@@ -999,8 +905,6 @@ cdma_device_added (NMDevice *device, NMApplet *applet)
 	                         G_TYPE_STRING, MM_DBUS_INTERFACE_MODEM,
 	                         G_TYPE_STRING, "Enabled",
 	                         G_TYPE_INVALID);
-
-	g_object_unref (dbus_mgr);
 }
 
 NMADeviceClass *
@@ -1017,6 +921,7 @@ applet_device_cdma_get_class (NMApplet *applet)
 	dclass->device_state_changed = cdma_device_state_changed;
 	dclass->get_icon = cdma_get_icon;
 	dclass->get_secrets = cdma_get_secrets;
+	dclass->secrets_request_size = sizeof (NMCdmaSecretsInfo);
 	dclass->device_added = cdma_device_added;
 
 	return dclass;
