@@ -17,7 +17,7 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * (C) Copyright 2008 - 2011 Red Hat, Inc.
+ * (C) Copyright 2008 - 2010 Red Hat, Inc.
  */
 
 #include <netinet/in.h>
@@ -27,8 +27,8 @@
 
 #include <nm-device-ethernet.h>
 #include <nm-device-wifi.h>
-#include <nm-gsm-device.h>
-#include <nm-cdma-device.h>
+#include <nm-device-modem.h>
+#include <nm-device-wimax.h>
 
 #include <nm-setting-connection.h>
 #include <nm-setting-wireless.h>
@@ -37,16 +37,12 @@
 #include <nm-setting-8021x.h>
 #include <nm-setting-ip4-config.h>
 #include <nm-setting-ip6-config.h>
-#include <nm-setting-vpn.h>
-#include <nm-vpn-connection.h>
 #include <nm-utils.h>
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
 #include "applet-dialogs.h"
-#include "utils.h"
-#include "nma-bling-spinner.h"
 
 
 static void
@@ -88,8 +84,7 @@ ip6_address_as_string (const struct in6_addr *ip)
 		g_string_append_printf (ip6_str, "%02X", ip->s6_addr[0]);
 		for (j = 1; j < 16; j++)
 			g_string_append_printf (ip6_str, " %02X", ip->s6_addr[j]);
-		nm_warning ("%s: error converting IP6 address %s",
-		            __func__, ip6_str->str);
+		g_warning ("%s: error converting IP6 address %s", __func__, ip6_str->str);
 		g_string_free (ip6_str, TRUE);
 		return NULL;
 	}
@@ -147,12 +142,8 @@ get_connection_for_active (NMApplet *applet, NMActiveConnection *active)
 {
 	GSList *list, *iter;
 	NMConnection *connection = NULL;
-	NMConnectionScope scope;
 	const char *path;
 
-	scope = nm_active_connection_get_scope (active);
-	g_return_val_if_fail (scope != NM_CONNECTION_SCOPE_UNKNOWN, NULL);
-
 	path = nm_active_connection_get_connection (active);
 	g_return_val_if_fail (path != NULL, NULL);
 
@@ -160,42 +151,16 @@ get_connection_for_active (NMApplet *applet, NMActiveConnection *active)
 	for (iter = list; iter; iter = g_slist_next (iter)) {
 		NMConnection *candidate = NM_CONNECTION (iter->data);
 
-		if (   (nm_connection_get_scope (candidate) == scope)
-			   && !strcmp (nm_connection_get_path (candidate), path)) {
+		if (!strcmp (nm_connection_get_path (candidate), path)) {
 			connection = candidate;
 			break;
 		}
 	}
-
 	g_slist_free (list);
 
 	return connection;
 }
 
-static NMConnection *
-get_connection_for_active_path (NMApplet *applet, const char *active_path)
-{
-	NMActiveConnection *active = NULL;
-	const GPtrArray *connections;
-	int i;
-
-	if (active_path == NULL)
-		return NULL;
-
-	connections = nm_client_get_active_connections (applet->nm_client);
-	for (i = 0; connections && (i < connections->len); i++) {
-		NMActiveConnection *candidate = g_ptr_array_index (connections, i);
-		const char *ac_path = nm_object_get_path (NM_OBJECT (candidate));
-
-		if (g_strcmp0 (ac_path, active_path) == 0) {
-			active = candidate;
-			break;
-		}
-	}
-
-	return active ? get_connection_for_active (applet, active) : NULL;
-}
-
 static GtkWidget *
 create_info_label (const char *text, gboolean selectable)
 {
@@ -226,7 +191,7 @@ create_info_label_security (NMConnection *connection)
 {
 	NMSettingConnection *s_con;
 	char *label = NULL;
-	GtkWidget *w;
+	GtkWidget *w = NULL;
 	const char *connection_type;
 
 	s_con = NM_SETTING_CONNECTION (nm_connection_get_setting (connection, NM_TYPE_SETTING_CONNECTION));
@@ -269,7 +234,8 @@ create_info_label_security (NMConnection *connection)
 			label = g_strdup (C_("Wifi/wired security", "None"));
 	}
 
-	w = create_info_label (label ? label : C_("Wifi/wired security", "Unknown"), TRUE);
+	if (label)
+		w = create_info_label (label, TRUE);
 	g_free (label);
 
 	return w;
@@ -300,12 +266,12 @@ typedef struct {
 	NMDevice *device;
 	GtkWidget *label;
 	guint32 id;
-} SpeedInfo;
+} LabelInfo;
 
 static void
 device_destroyed (gpointer data, GObject *device_ptr)
 {
-	SpeedInfo *info = data;
+	LabelInfo *info = data;
 
 	/* Device is destroyed, notify handler won't fire
 	 * anymore anyway.  Let the label destroy handler
@@ -318,18 +284,35 @@ device_destroyed (gpointer data, GObject *device_ptr)
 static void
 label_destroyed (gpointer data, GObject *label_ptr)
 {
-	SpeedInfo *info = data;
+	LabelInfo *info = data;
+
 	/* Remove the notify handler from the device */
 	if (info->device) {
 		if (info->id)
 			g_signal_handler_disconnect (info->device, info->id);
 		/* destroy our info data */
 		g_object_weak_unref (G_OBJECT (info->device), device_destroyed, info);
-		memset (info, 0, sizeof (SpeedInfo));
+		memset (info, 0, sizeof (LabelInfo));
 		g_free (info);
 	}
 }
 
+static void
+label_info_new (NMDevice *device,
+                GtkWidget *label,
+                const char *notify_prop,
+                GCallback callback)
+{
+	LabelInfo *info;
+
+	info = g_malloc0 (sizeof (LabelInfo));
+	info->device = device;
+	info->label = label;
+	info->id = g_signal_connect (device, notify_prop, callback, label);
+	g_object_weak_ref (G_OBJECT (label), label_destroyed, info);
+	g_object_weak_ref (G_OBJECT (device), device_destroyed, info);
+}
+
 static void
 bitrate_changed_cb (GObject *device, GParamSpec *pspec, gpointer user_data)
 {
@@ -345,6 +328,33 @@ bitrate_changed_cb (GObject *device, GParamSpec *pspec, gpointer user_data)
 	g_free (str);
 }
 
+static void
+wimax_cinr_changed_cb (NMDevice *device, GParamSpec *pspec, gpointer user_data)
+{
+	GtkWidget *label = GTK_WIDGET (user_data);
+	gint cinr;
+	char *str = NULL;
+
+	cinr = nm_device_wimax_get_cinr (NM_DEVICE_WIMAX (device));
+	if (cinr)
+		str = g_strdup_printf (_("%d dB"), cinr);
+
+	gtk_label_set_text (GTK_LABEL (label), str ? str : C_("WiMAX CINR", "unknown"));
+	g_free (str);
+}
+
+static void
+wimax_bsid_changed_cb (NMDevice *device, GParamSpec *pspec, gpointer user_data)
+{
+	GtkWidget *label = GTK_WIDGET (user_data);
+	const char *str = NULL;
+
+	str = nm_device_wimax_get_bsid (NM_DEVICE_WIMAX (device));
+	if (!str)
+		str = C_("WiMAX Base Station ID", "unknown");
+	gtk_label_set_text (GTK_LABEL (label), str);
+}
+
 static void
 info_dialog_add_page (GtkNotebook *notebook,
                       NMConnection *connection,
@@ -364,9 +374,9 @@ info_dialog_add_page (GtkNotebook *notebook,
 	NMSettingIP6Config *s_ip6;
 	guint32 hostmask, network, bcast, netmask;
 	int i, row = 0;
-	SpeedInfo* info = NULL;
-	GtkWidget* speed_label;
+	GtkWidget* speed_label, *sec_label = NULL;
 	const GSList *addresses;
+	gboolean show_security = FALSE;
 
 	table = GTK_TABLE (gtk_table_new (12, 2, FALSE));
 	gtk_table_set_col_spacings (table, 12);
@@ -375,14 +385,24 @@ info_dialog_add_page (GtkNotebook *notebook,
 
 	/* Interface */
 	iface = nm_device_get_iface (device);
-	if (NM_IS_DEVICE_ETHERNET (device))
+	if (NM_IS_DEVICE_ETHERNET (device)) {
 		str = g_strdup_printf (_("Ethernet (%s)"), iface);
-	else if (NM_IS_DEVICE_WIFI (device))
+		show_security = TRUE;
+	} else if (NM_IS_DEVICE_WIFI (device)) {
 		str = g_strdup_printf (_("802.11 WiFi (%s)"), iface);
-	else if (NM_IS_GSM_DEVICE (device))
-		str = g_strdup_printf (_("GSM (%s)"), iface);
-	else if (NM_IS_CDMA_DEVICE (device))
-		str = g_strdup_printf (_("CDMA (%s)"), iface);
+		show_security = TRUE;
+	} else if (NM_IS_DEVICE_MODEM (device)) {
+		NMDeviceModemCapabilities caps;
+
+		caps = nm_device_modem_get_current_capabilities (NM_DEVICE_MODEM (device));
+		if (caps & NM_DEVICE_MODEM_CAPABILITY_GSM_UMTS)
+			str = g_strdup_printf (_("GSM (%s)"), iface);
+		else if (caps & NM_DEVICE_MODEM_CAPABILITY_CDMA_EVDO)
+			str = g_strdup_printf (_("CDMA (%s)"), iface);
+		else
+			str = g_strdup_printf (_("Mobile Broadband (%s)"), iface);
+	} else if (NM_IS_DEVICE_WIMAX (device))
+		str = g_strdup_printf (_("WiMAX (%s)"), iface);
 	else
 		str = g_strdup (iface);
 
@@ -405,6 +425,8 @@ info_dialog_add_page (GtkNotebook *notebook,
 		str = g_strdup (nm_device_ethernet_get_hw_address (NM_DEVICE_ETHERNET (device)));
 	else if (NM_IS_DEVICE_WIFI (device))
 		str = g_strdup (nm_device_wifi_get_hw_address (NM_DEVICE_WIFI (device)));
+	else if (NM_IS_DEVICE_WIMAX (device))
+		str = g_strdup (nm_device_wimax_get_hw_address (NM_DEVICE_WIMAX (device)));
 
 	gtk_table_attach (table, create_info_label (_("Hardware Address:"), FALSE),
 	                  0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
@@ -431,17 +453,10 @@ info_dialog_add_page (GtkNotebook *notebook,
 		/* Wireless speed in Kb/s */
 		speed = nm_device_wifi_get_bitrate (NM_DEVICE_WIFI (device)) / 1000;
 
-		/* Listen for wifi speed changes */
-		info = g_malloc0 (sizeof (SpeedInfo));
-		info->device = device;
-		info->label = speed_label;
-		info->id = g_signal_connect (device,
-		                             "notify::" NM_DEVICE_WIFI_BITRATE,
-		                             G_CALLBACK (bitrate_changed_cb),
-		                             speed_label);
-
-		g_object_weak_ref (G_OBJECT(speed_label), label_destroyed, info);
-		g_object_weak_ref (G_OBJECT(device), device_destroyed, info);
+		label_info_new (device,
+		                speed_label,
+		                "notify::" NM_DEVICE_WIFI_BITRATE,
+		                G_CALLBACK (bitrate_changed_cb));
 	}
 
 	if (speed)
@@ -457,11 +472,46 @@ info_dialog_add_page (GtkNotebook *notebook,
 	row++;
 
 	/* Security */
-	gtk_table_attach (table, create_info_label (_("Security:"), FALSE),
-	                  0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
-	gtk_table_attach (table, create_info_label_security (connection),
-	                  1, 2, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
-	row++;
+	if (show_security) {
+		sec_label = create_info_label_security (connection);
+		if (sec_label) {
+			gtk_table_attach (table, create_info_label (_("Security:"), FALSE),
+				              0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
+			gtk_table_attach (table, sec_label,
+				              1, 2, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
+			row++;
+		}
+	}
+
+	if (NM_IS_DEVICE_WIMAX (device)) {
+		GtkWidget *bsid_label, *cinr_label;
+
+		/* CINR */
+		cinr_label = create_info_label ("", TRUE);
+		gtk_table_attach (table, create_info_label (_("CINR:"), FALSE),
+			              0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
+		gtk_table_attach (table, cinr_label,
+			              1, 2, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
+		label_info_new (device,
+		                cinr_label,
+		                "notify::" NM_DEVICE_WIMAX_CINR,
+		                G_CALLBACK (wimax_cinr_changed_cb));
+		wimax_cinr_changed_cb (device, NULL, cinr_label);
+		row++;
+
+		/* Base Station ID */
+		bsid_label = create_info_label ("", TRUE);
+		gtk_table_attach (table, create_info_label (_("BSID:"), FALSE),
+			              0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
+		gtk_table_attach (table, bsid_label,
+			              1, 2, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
+		label_info_new (device,
+		                bsid_label,
+		                "notify::" NM_DEVICE_WIMAX_BSID,
+		                G_CALLBACK (wimax_bsid_changed_cb));
+		wimax_bsid_changed_cb (device, NULL, bsid_label);
+		row++;
+	}
 
 	/* Empty line */
 	gtk_table_attach (table, gtk_label_new (""), 0, 2, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
@@ -631,144 +681,6 @@ info_dialog_add_page (GtkNotebook *notebook,
 	gtk_widget_show_all (GTK_WIDGET (table));
 }
 
-static char *
-get_vpn_connection_type (NMConnection *connection)
-{
-	NMSettingVPN *s_vpn;
-	const char *type, *p;
-
-	/* The service type is in format of "org.freedesktop.NetworkManager.vpnc".
-	 * Extract end part after last dot, e.g. "vpnc" */
-	s_vpn = (NMSettingVPN *) nm_connection_get_setting (connection, NM_TYPE_SETTING_VPN);
-	type = nm_setting_vpn_get_service_type (s_vpn);
-	p = strrchr (type, '.');
-	return g_strdup (p ? p + 1 : type);
-}
-
-/* VPN parameters can be found at:
- * http://git.gnome.org/browse/network-manager-openvpn/tree/src/nm-openvpn-service.h
- * http://git.gnome.org/browse/network-manager-vpnc/tree/src/nm-vpnc-service.h
- * http://git.gnome.org/browse/network-manager-pptp/tree/src/nm-pptp-service.h
- * http://git.gnome.org/browse/network-manager-openconnect/tree/src/nm-openconnect-service.h
- * http://git.gnome.org/browse/network-manager-openswan/tree/src/nm-openswan-service.h
- * See also 'properties' directory in these plugins.
- */
-static const gchar *
-find_vpn_gateway_key (const char *vpn_type)
-{
-	if (g_strcmp0 (vpn_type, "openvpn") == 0)     return "remote";
-	if (g_strcmp0 (vpn_type, "vpnc") == 0)        return "IPSec gateway";
-	if (g_strcmp0 (vpn_type, "pptp") == 0)        return "gateway";
-	if (g_strcmp0 (vpn_type, "openconnect") == 0) return "gateway";
-	if (g_strcmp0 (vpn_type, "openswan") == 0)    return "right";
-	return "";
-}
-
-static const gchar *
-find_vpn_username_key (const char *vpn_type)
-{
-	if (g_strcmp0 (vpn_type, "openvpn") == 0)     return "username";
-	if (g_strcmp0 (vpn_type, "vpnc") == 0)        return "Xauth username";
-	if (g_strcmp0 (vpn_type, "pptp") == 0)        return "user";
-	if (g_strcmp0 (vpn_type, "openconnect") == 0) return "username";
-	if (g_strcmp0 (vpn_type, "openswan") == 0)    return "leftxauthusername";
-	return "";
-}
-
-enum VpnDataItem {
-	VPN_DATA_ITEM_GATEWAY,
-	VPN_DATA_ITEM_USERNAME
-};
-
-static const gchar *
-get_vpn_data_item (NMConnection *connection, enum VpnDataItem vpn_data_item)
-{
-	NMSettingVPN *s_vpn;
-	const char *key;
-	char *type = get_vpn_connection_type (connection);
-
-	switch (vpn_data_item) {
-	case VPN_DATA_ITEM_GATEWAY:
-		key = find_vpn_gateway_key (type);
-		break;
-	case VPN_DATA_ITEM_USERNAME:
-		key = find_vpn_username_key (type);
-		break;
-	default:
-		key = "";
-		break;
-	}
-	g_free (type);
-
-	s_vpn = (NMSettingVPN *) nm_connection_get_setting (connection, NM_TYPE_SETTING_VPN);
-	return nm_setting_vpn_get_data_item (s_vpn, key);
-}
-
-static void
-info_dialog_add_page_for_vpn (GtkNotebook *notebook,
-                              NMConnection *connection,
-                              NMActiveConnection *active,
-                              NMConnection *parent_con)
-{
-	GtkTable *table;
-	char *str;
-	int row = 0;
-	gboolean is_default = nm_active_connection_get_default (active);
-	NMSettingConnection *s_con;
-	const char *id = _("Unknown");
-
-	if (parent_con) {
-		s_con = (NMSettingConnection *) nm_connection_get_setting (parent_con, NM_TYPE_SETTING_CONNECTION);
-		id = nm_setting_connection_get_id (s_con);
-	}
-
-	table = GTK_TABLE (gtk_table_new (12, 2, FALSE));
-	gtk_table_set_col_spacings (table, 12);
-	gtk_table_set_row_spacings (table, 6);
-	gtk_container_set_border_width (GTK_CONTAINER (table), 12);
-
-	/*--- General ---*/
-	gtk_table_attach (table, create_info_group_label (_("General"), FALSE),
-	                  0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
-	row++;
-
-	str = get_vpn_connection_type (connection);
-	gtk_table_attach (table, create_info_label (_("VPN Type:"), FALSE),
-	                  0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
-	gtk_table_attach (table, create_info_label (str, TRUE),
-	                  1, 2, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
-	g_free (str);
-	row++;
-
-	gtk_table_attach (table, create_info_label (_("VPN Gateway:"), FALSE),
-	                  0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
-	gtk_table_attach (table, create_info_label (get_vpn_data_item (connection, VPN_DATA_ITEM_GATEWAY), TRUE),
-	                  1, 2, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
-	row++;
-
-	gtk_table_attach (table, create_info_label (_("VPN Username:"), FALSE),
-	                  0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
-	gtk_table_attach (table, create_info_label (get_vpn_data_item (connection, VPN_DATA_ITEM_USERNAME), TRUE),
-	                  1, 2, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
-	row++;
-
-	gtk_table_attach (table, create_info_label (_("VPN Banner:"), FALSE),
-	                  0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
-	gtk_table_attach (table, create_info_label (nm_vpn_connection_get_banner (NM_VPN_CONNECTION (active)), TRUE),
-	                  1, 2, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
-	row++;
-
-	gtk_table_attach (table, create_info_label (_("Base Connection:"), FALSE),
-	                  0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
-	gtk_table_attach (table, create_info_label (id, TRUE),
-	                  1, 2, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
-
-	gtk_notebook_append_page (notebook, GTK_WIDGET (table),
-	                          create_info_notebook_label (connection, is_default));
-
-	gtk_widget_show_all (GTK_WIDGET (table));
-}
-
 static GtkWidget *
 info_dialog_update (NMApplet *applet)
 {
@@ -793,31 +705,23 @@ info_dialog_update (NMApplet *applet)
 		if (nm_active_connection_get_state (active_connection) != NM_ACTIVE_CONNECTION_STATE_ACTIVATED)
 			continue;
 
+		devices = nm_active_connection_get_devices (active_connection);
+		if (!devices || !devices->len) {
+			g_warning ("Active connection %s had no devices!",
+					   nm_object_get_path (NM_OBJECT (active_connection)));
+			continue;
+		}
+
 		connection = get_connection_for_active (applet, active_connection);
 		if (!connection) {
 			g_warning ("%s: couldn't find the default active connection's NMConnection!", __func__);
 			continue;
 		}
-
-		devices = nm_active_connection_get_devices (active_connection);
-		if (devices && devices->len > 0)
-			info_dialog_add_page (notebook,
-			                      connection,
-			                      nm_active_connection_get_default (active_connection),
-			                      g_ptr_array_index (devices, 0));
-		else {
-			if (NM_IS_VPN_CONNECTION (active_connection)) {
-				const char *spec_object = nm_active_connection_get_specific_object (active_connection);
-				NMConnection *parent_con = get_connection_for_active_path (applet, spec_object);
-
-				info_dialog_add_page_for_vpn (notebook, connection, active_connection, parent_con);
-			} else {
-				g_warning ("Active connection %s had no devices and was not a VPN!",
-				           nm_object_get_path (NM_OBJECT (active_connection)));
-				continue;
-			}
-		}
-
+			
+		info_dialog_add_page (notebook,
+							  connection,
+							  nm_active_connection_get_default (active_connection),
+							  g_ptr_array_index (devices, 0));
 		pages++;
 	}
 
@@ -909,14 +813,12 @@ applet_warning_dialog_show (const char *message)
 }
 
 GtkWidget *
-applet_mobile_password_dialog_new (NMDevice *device,
-                                   NMConnection *connection,
+applet_mobile_password_dialog_new (NMConnection *connection,
                                    GtkEntry **out_secret_entry)
 {
 	GtkDialog *dialog;
 	GtkWidget *w;
 	GtkBox *box = NULL, *vbox = NULL;
-	char *dev_str;
 	NMSettingConnection *s_con;
 	char *tmp;
 	const char *id;
@@ -940,12 +842,6 @@ applet_mobile_password_dialog_new (NMDevice *device,
 
 	gtk_box_pack_start (vbox, w, TRUE, TRUE, 0);
 
-	dev_str = g_strdup_printf ("<b>%s</b>", utils_get_device_description (device));
-	w = gtk_label_new (NULL);
-	gtk_label_set_markup (GTK_LABEL (w), dev_str);
-	g_free (dev_str);
-	gtk_box_pack_start (vbox, w, TRUE, TRUE, 0);
-
 	w = gtk_alignment_new (0.5, 0.5, 0, 1.0);
 	gtk_box_pack_start (vbox, w, TRUE, TRUE, 0);
 
@@ -1062,8 +958,7 @@ GtkWidget *
 applet_mobile_pin_dialog_new (const char *title,
                               const char *header,
                               const char *desc,
-                              const char *show_password_label,
-                              gboolean show_auto_unlock_checkbox)
+                              const char *show_password_label)
 {
 	char *str;
 	GtkWidget *dialog;
@@ -1078,7 +973,7 @@ applet_mobile_pin_dialog_new (const char *title,
 
 	builder = gtk_builder_new ();
 
-	if (!gtk_builder_add_from_file (builder, UIDIR "/gsm-unlock.ui", &error)) {
+	if (!gtk_builder_add_from_file (builder, UIDIR "/applet.ui", &error)) {
 		g_warning ("Couldn't load builder file: %s", error->message);
 		g_error_free (error);
 		g_object_unref (builder);
@@ -1112,10 +1007,6 @@ applet_mobile_pin_dialog_new (const char *title,
 
 	g_signal_connect (dialog, "delete-event", G_CALLBACK (mpd_cancel_dialog), NULL);
 
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "save_checkbutton"));
-	if (show_auto_unlock_checkbox)
-		g_object_set_data (G_OBJECT (widget), "active", GUINT_TO_POINTER (TRUE));
-
 	mpd_entry_changed (NULL, dialog);
 
 	return dialog;
@@ -1152,10 +1043,6 @@ applet_mobile_pin_dialog_present (GtkWidget *dialog, gboolean now)
 		gtk_widget_hide (widget);
 	}
 
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "save_checkbutton"));
-	if (!g_object_get_data (G_OBJECT (widget), "active"))
-		gtk_widget_hide (widget);
-
 	/* Need to resize the dialog after hiding widgets */
 	gtk_window_resize (GTK_WINDOW (dialog), 400, 100);
 
@@ -1310,20 +1197,6 @@ applet_mobile_pin_dialog_get_entry3 (GtkWidget *dialog)
 	return mpd_get_entry (dialog, "code3_entry");
 }
 
-gboolean
-applet_mobile_pin_dialog_get_auto_unlock (GtkWidget *dialog)
-{
-	GtkBuilder *builder;
-	GtkWidget *widget;
-
-	g_return_val_if_fail (dialog != NULL, FALSE);
-	builder = g_object_get_data (G_OBJECT (dialog), "builder");
-	g_return_val_if_fail (builder != NULL, FALSE);
-
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "save_checkbutton"));
-	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-}
-
 void
 applet_mobile_pin_dialog_start_spinner (GtkWidget *dialog, const char *text)
 {
@@ -1336,13 +1209,13 @@ applet_mobile_pin_dialog_start_spinner (GtkWidget *dialog, const char *text)
 	builder = g_object_get_data (G_OBJECT (dialog), "builder");
 	g_return_if_fail (builder != NULL);
 
-	spinner = nma_bling_spinner_new ();
+	spinner = gtk_spinner_new ();
 	g_return_if_fail (spinner != NULL);
 	g_object_set_data (G_OBJECT (dialog), "spinner", spinner);
 
 	align = GTK_WIDGET (gtk_builder_get_object (builder, "spinner_alignment"));
 	gtk_container_add (GTK_CONTAINER (align), spinner);
-	nma_bling_spinner_start (NMA_BLING_SPINNER (spinner));
+	gtk_spinner_start (GTK_SPINNER (spinner));
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "progress_label"));
 	gtk_label_set_text (GTK_LABEL (widget), text);
@@ -1380,7 +1253,7 @@ applet_mobile_pin_dialog_stop_spinner (GtkWidget *dialog, const char *text)
 
 	spinner = g_object_get_data (G_OBJECT (dialog), "spinner");
 	g_return_if_fail (spinner != NULL);
-	nma_bling_spinner_stop (NMA_BLING_SPINNER (spinner));
+	gtk_spinner_stop (GTK_SPINNER (spinner));
 	g_object_set_data (G_OBJECT (dialog), "spinner", NULL);
 
 	/* Remove it from the alignment */
