@@ -34,7 +34,6 @@
 
 #include "page-mobile.h"
 #include "nm-connection-editor.h"
-#include "gconf-helpers.h"
 #include "mobile-wizard.h"
 
 G_DEFINE_TYPE (CEPageMobile, ce_page_mobile, CE_TYPE_PAGE)
@@ -117,19 +116,19 @@ populate_gsm_ui (CEPageMobile *self, NMConnection *connection)
 		gtk_entry_set_text (priv->network_id, s);
 
 	switch (nm_setting_gsm_get_network_type (setting)) {
-	case NM_GSM_NETWORK_UMTS_HSPA:
+	case NM_SETTING_GSM_NETWORK_TYPE_UMTS_HSPA:
 		type_idx = NET_TYPE_3G;
 		break;
-	case NM_GSM_NETWORK_GPRS_EDGE:
+	case NM_SETTING_GSM_NETWORK_TYPE_GPRS_EDGE:
 		type_idx = NET_TYPE_2G;
 		break;
-	case NM_GSM_NETWORK_PREFER_UMTS_HSPA:
+	case NM_SETTING_GSM_NETWORK_TYPE_PREFER_UMTS_HSPA:
 		type_idx = NET_TYPE_PREFER_3G;
 		break;
-	case NM_GSM_NETWORK_PREFER_GPRS_EDGE:
+	case NM_SETTING_GSM_NETWORK_TYPE_PREFER_GPRS_EDGE:
 		type_idx = NET_TYPE_PREFER_2G;
 		break;
-	case NM_GSM_NETWORK_ANY:
+	case NM_SETTING_GSM_NETWORK_TYPE_ANY:
 	default:
 		type_idx = NET_TYPE_ANY;
 		break;
@@ -206,7 +205,7 @@ apn_button_mobile_wizard_done (MobileWizard *wizard,
 
 	if (!canceled && method) {
 		switch (method->devtype) {
-		case NM_DEVICE_TYPE_GSM:
+		case NM_DEVICE_MODEM_CAPABILITY_GSM_UMTS:
 			gtk_entry_set_text (GTK_ENTRY (priv->username),
 			                    method->username ? method->username : "");
 			gtk_entry_set_text (GTK_ENTRY (priv->password),
@@ -214,6 +213,12 @@ apn_button_mobile_wizard_done (MobileWizard *wizard,
 			gtk_entry_set_text (GTK_ENTRY (priv->apn),
 			                    method->gsm_apn ? method->gsm_apn : "");
 			break;
+		case NM_DEVICE_MODEM_CAPABILITY_CDMA_EVDO:
+			gtk_entry_set_text (GTK_ENTRY (priv->username),
+			                    method->username ? method->username : "");
+			gtk_entry_set_text (GTK_ENTRY (priv->password),
+			                    method->password ? method->password : "");
+			break;
 		default:
 			g_assert_not_reached ();
 			break;
@@ -241,7 +246,7 @@ apn_button_clicked (GtkButton *button, gpointer user_data)
 
 	wizard = mobile_wizard_new (GTK_WINDOW (toplevel),
 	                            priv->window_group,
-	                            NM_DEVICE_TYPE_GSM,
+	                            NM_DEVICE_MODEM_CAPABILITY_GSM_UMTS,
 	                            FALSE,
 	                            apn_button_mobile_wizard_done,
 	                            self);
@@ -258,9 +263,7 @@ network_id_filter_cb (GtkEntry *   entry,
 {
 	GtkEditable *editable = GTK_EDITABLE (entry);
 	int i, count = 0;
-	gchar *result;
-
-	result = g_malloc0 (length + 1);
+	gchar *result = g_new0 (gchar, length);
 
 	for (i = 0; i < length; i++) {
 		if (isdigit (text[i]))
@@ -293,10 +296,7 @@ apn_filter_cb (GtkEntry *   entry,
 	gchar *result = g_new0 (gchar, length);
 
 	for (i = 0; i < length; i++) {
-		if (   isalnum (text[i])
-		    || (text[i] == '.')
-		    || (text[i] == '_')
-		    || (text[i] == '-'))
+		if (isalnum (text[i]) || (text[i] == '.') || (text[i] == '-'))
 			result[count++] = text[i];
 	}
 
@@ -417,20 +417,20 @@ gsm_ui_to_setting (CEPageMobile *self)
 
 	switch (gtk_combo_box_get_active (priv->network_type)) {
 	case NET_TYPE_3G:
-		net_type = NM_GSM_NETWORK_UMTS_HSPA;
+		net_type = NM_SETTING_GSM_NETWORK_TYPE_UMTS_HSPA;
 		break;
 	case NET_TYPE_2G:
-		net_type = NM_GSM_NETWORK_GPRS_EDGE;
+		net_type = NM_SETTING_GSM_NETWORK_TYPE_GPRS_EDGE;
 		break;
 	case NET_TYPE_PREFER_3G:
-		net_type = NM_GSM_NETWORK_PREFER_UMTS_HSPA;
+		net_type = NM_SETTING_GSM_NETWORK_TYPE_PREFER_UMTS_HSPA;
 		break;
 	case NET_TYPE_PREFER_2G:
-		net_type = NM_GSM_NETWORK_PREFER_GPRS_EDGE;
+		net_type = NM_SETTING_GSM_NETWORK_TYPE_PREFER_GPRS_EDGE;
 		break;
 	case NET_TYPE_ANY:
 	default:
-		net_type = NM_GSM_NETWORK_ANY;
+		net_type = NM_SETTING_GSM_NETWORK_TYPE_ANY;
 		break;
 	}
 
@@ -550,7 +550,7 @@ new_connection_mobile_wizard_done (MobileWizard *wizard,
 		char *detail = NULL;
 
 		switch (method->devtype) {
-		case NM_DEVICE_TYPE_GSM:
+		case NM_DEVICE_MODEM_CAPABILITY_GSM_UMTS:
 			ctype = NM_SETTING_GSM_SETTING_NAME;
 			type_setting = nm_setting_gsm_new ();
 			/* De-facto standard for GSM */
@@ -561,7 +561,7 @@ new_connection_mobile_wizard_done (MobileWizard *wizard,
 			              NM_SETTING_GSM_APN, method->gsm_apn,
 			              NULL);
 			break;
-		case NM_DEVICE_TYPE_CDMA:
+		case NM_DEVICE_MODEM_CAPABILITY_CDMA_EVDO:
 			ctype = NM_SETTING_CDMA_SETTING_NAME;
 			type_setting = nm_setting_cdma_new ();
 			/* De-facto standard for CDMA */
@@ -619,7 +619,7 @@ mobile_connection_new (GtkWindow *parent,
 	info->get_connections_func = get_connections_func;
 	info->user_data = user_data;
 
-	wizard = mobile_wizard_new (parent, NULL, NM_DEVICE_TYPE_UNKNOWN, FALSE,
+	wizard = mobile_wizard_new (parent, NULL, NM_DEVICE_MODEM_CAPABILITY_NONE, FALSE,
 	                            new_connection_mobile_wizard_done, info);
 	if (wizard) {
 		mobile_wizard_present (wizard);
@@ -675,10 +675,10 @@ mobile_connection_new (GtkWindow *parent,
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 	if (response == GTK_RESPONSE_OK) {
 		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cdma_radio))) {
-			method.devtype = NM_DEVICE_TYPE_CDMA;
+			method.devtype = NM_DEVICE_MODEM_CAPABILITY_CDMA_EVDO;
 			method.provider_name = _("CDMA");
 		} else {
-			method.devtype = NM_DEVICE_TYPE_GSM;
+			method.devtype = NM_DEVICE_MODEM_CAPABILITY_GSM_UMTS;
 			method.provider_name = _("GSM");
 		}
 	}
