@@ -25,8 +25,6 @@
 #include <nm-setting-wireless.h>
 
 #include "wireless-security.h"
-#include "utils.h"
-#include "gconf-helpers.h"
 #include "helpers.h"
 
 #define WPA_PMK_LEN 32
@@ -147,7 +145,7 @@ update_secrets (WirelessSecurity *parent, NMConnection *connection)
 }
 
 WirelessSecurityWPAPSK *
-ws_wpa_psk_new (NMConnection *connection, gboolean secrets_only)
+ws_wpa_psk_new (NMConnection *connection)
 {
 	WirelessSecurity *parent;
 	WirelessSecurityWPAPSK *sec;
@@ -184,10 +182,6 @@ ws_wpa_psk_new (NMConnection *connection, gboolean secrets_only)
 	                  (GCallback) show_toggled_cb,
 	                  sec);
 
-	/* Hide WPA/RSN for now since this can be autodetected by NM and the
-	 * supplicant when connecting to the AP.
-	 */
-
 	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wpa_psk_type_combo"));
 	g_assert (widget);
 	gtk_widget_hide (widget);
